@@ -1,26 +1,48 @@
 package Log::Dispatch;
-BEGIN {
-  $Log::Dispatch::VERSION = '2.29';
-}
 
 use 5.006;
 
 use strict;
 use warnings;
 
+our $VERSION = '2.51';
+
 use base qw( Log::Dispatch::Base );
-use Params::Validate qw(validate_with ARRAYREF CODEREF);
+
+use Module::Runtime qw( use_package_optimistically );
+use Params::Validate 1.03 qw(validate_with ARRAYREF CODEREF);
 use Carp ();
 
 our %LEVELS;
 
 BEGIN {
-    foreach my $l (
-        qw( debug info notice warn warning err error crit critical alert emerg emergency )
-        ) {
+    my %level_map = (
+        (
+            map { $_ => $_ }
+                qw(
+                debug
+                info
+                notice
+                warning
+                error
+                critical
+                alert
+                emergency
+                )
+        ),
+        warn  => 'warning',
+        err   => 'error',
+        crit  => 'critical',
+        emerg => 'emergency',
+    );
+
+    foreach my $l ( keys %level_map ) {
         my $sub = sub {
             my $self = shift;
-            $self->log( level => $l, message => "@_" );
+            $self->log(
+                level => $level_map{$l},
+                message => @_ > 1 ? "@_" : $_[0],
+            );
         };
 
         $LEVELS{$l} = 1;
@@ -37,7 +59,7 @@ sub new {
     my %p = validate_with(
         params => \@_,
         spec   => {
-            outputs   => { type => ARRAYREF,           optional => 1 },
+            outputs => { type => ARRAYREF, optional => 1 },
             callbacks => { type => ARRAYREF | CODEREF, optional => 1 }
         },
         allow_extra => 1,    # for backward compatibility
@@ -78,6 +100,17 @@ sub new {
     return $self;
 }
 
+sub clone {
+    my $self = shift;
+
+    my %clone = (
+        callbacks => [ @{ $self->{callbacks} || [] } ],
+        outputs   => { %{ $self->{outputs}   || {} } },
+    );
+
+    return bless \%clone, ref $self;
+}
+
 sub _add_output {
     my $self  = shift;
     my $class = shift;
@@ -87,7 +120,7 @@ sub _add_output {
         ? substr( $class, 1 )
         : "Log::Dispatch::$class";
 
-    _require_dynamic($full_class);
+    use_package_optimistically($full_class);
 
     $self->add( $full_class->new(@_) );
 }
@@ -114,6 +147,18 @@ sub remove {
     return delete $self->{outputs}{$name};
 }
 
+sub outputs {
+    my $self = shift;
+
+    return values %{ $self->{outputs} };
+}
+
+sub callbacks {
+    my $self = shift;
+
+    return @{ $self->{callbacks} };
+}
+
 sub log {
     my $self = shift;
     my %p    = @_;
@@ -209,7 +254,10 @@ sub output {
 
 sub level_is_valid {
     shift;
-    return $LEVELS{ shift() };
+    my $level = shift
+        or Carp::croak('Logging level was not provided');
+
+    return $LEVELS{$level};
 }
 
 sub would_log {
@@ -238,19 +286,11 @@ sub is_alert     { $_[0]->would_log('alert') }
 sub is_emerg     { $_[0]->would_log('emerg') }
 sub is_emergency { $_[0]->would_log('emergency') }
 
-sub _require_dynamic {
-    my ($class) = @_;
-
-    local $@;
-    eval "require $class";
-    die $@ if $@;
-}
-
 1;
 
 # ABSTRACT: Dispatches messages to one or more outputs
 
-
+__END__
 
 =pod
 
@@ -260,7 +300,7 @@ Log::Dispatch - Dispatches messages to one or more outputs
 
 =head1 VERSION
 
-version 2.29
+version 2.51
 
 =head1 SYNOPSIS
 
@@ -305,7 +345,7 @@ This module manages a set of Log::Dispatch::* output objects that can be
 logged to via a unified interface.
 
 The idea is that you create a Log::Dispatch object and then add various
-logging objects to it (such as a file logger or screen logger).  Then you
+logging objects to it (such as a file logger or screen logger). Then you
 call the C<log> method of the dispatch object, which passes the message to
 each of the objects, which in turn decide whether or not to accept the
 message and what to do with it.
@@ -315,9 +355,15 @@ log file, via email, to the screen, and anywhere else, all with very
 little code needed on your part, once the dispatching object has been
 created.
 
-=head1 CONSTRUCTOR
+=encoding UTF-8
 
-The constructor (C<new>) takes the following parameters:
+=head1 METHODS
+
+This class provides the following methods:
+
+=head2 Log::Dispatch->new(...)
+
+This method takes the following parameters:
 
 =over 4
 
@@ -332,7 +378,7 @@ string following '+' is taken to be a full classname. e.g.
                  [ '+My::Dispatch', min_level => 'info' ] ]
 
 For each inner list, a new output object is created and added to the
-dispatcher (via L</add>).
+dispatcher (via the C<add()> method).
 
 See L<OUTPUT CLASSES> for the parameters that can be used when creating an
 output object.
@@ -340,7 +386,7 @@ output object.
 =item * callbacks( \& or [ \&, \&, ... ] )
 
 This parameter may be a single subroutine reference or an array
-reference of subroutine references.  These callbacks will be called in
+reference of subroutine references. These callbacks will be called in
 the order they are given and passed a hash containing the following keys:
 
  ( message => $log_message, level => $log_level )
@@ -349,21 +395,21 @@ In addition, any key/value pairs passed to a logging method will be
 passed onto your callback.
 
 The callbacks are expected to modify the message and then return a
-single scalar containing that modified message.  These callbacks will
+single scalar containing that modified message. These callbacks will
 be called when either the C<log> or C<log_to> methods are called and
-will only be applied to a given message once.  If they do not return
-the message then you will get no output.  Make sure to return the
+will only be applied to a given message once. If they do not return
+the message then you will get no output. Make sure to return the
 message!
 
 =back
 
-=head1 METHODS
+=head2 $dispatch->clone()
 
-=head2 Logging
+This returns a I<shallow> clone of the original object. The underlying output
+objects and callbacks are shared between the two objects. However any changes
+made to the outputs or callbacks that the object contains are not shared.
 
-=over 4
-
-=item * log( level => $, message => $ or \& )
+=head2 $dispatch->log( level => $, message => $ or \& )
 
 Sends the message (at the appropriate level) to all the
 output objects that the dispatcher contains (by calling the
@@ -373,10 +419,10 @@ This method also accepts a subroutine reference as the message
 argument. This reference will be called only if there is an output
 that will accept a message of the specified level.
 
-=item * debug (message), info (message), ...
+=head2 $dispatch->debug (message), info (message), ...
 
 You may call any valid log level (including valid abbreviations) as a method
-with a single argument that is the message to be logged.  This is converted
+with a single argument that is the message to be logged. This is converted
 into a call to the C<log> method with the appropriate level.
 
 For example:
@@ -389,92 +435,89 @@ translates to:
 
 If you pass an array to these methods, it will be stringified as is:
 
- my @array = ('Something', 'bad', 'is', here');
+ my @array = ('Something', 'bad', 'is', 'here');
  $log->alert(@array);
 
  # is equivalent to
 
  $log->alert("@array");
 
-=item * log_and_die( level => $, message => $ or \& )
+You can also pass a subroutine reference, just like passing one to the
+C<log()> method.
+
+=head2 $dispatch->log_and_die( level => $, message => $ or \& )
 
 Has the same behavior as calling C<log()> but calls
 C<_die_with_message()> at the end.
 
-=item * log_and_croak( level => $, message => $ or \& )
+=head2 $dispatch->log_and_croak( level => $, message => $ or \& )
 
 This method adjusts the C<$Carp::CarpLevel> scalar so that the croak
 comes from the context in which it is called.
 
-=item * _die_with_message( message => $, carp_level => $ )
-
-This method is used by C<log_and_die> and will either die() or croak()
-depending on the value of C<message>: if it's a reference or it ends
-with a new line then a plain die will be used, otherwise it will
-croak.
-
 You can throw exception objects by subclassing this method.
 
 If the C<carp_level> parameter is present its value will be added to
 the current value of C<$Carp::CarpLevel>.
 
-=item * log_to( name => $, level => $, message => $ )
+=head2 $dispatch->log_to( name => $, level => $, message => $ )
 
 Sends the message only to the named object. Note: this will not properly
 handle a subroutine reference as the message.
 
-=item * add_callback( $code )
+=head2 $dispatch->add_callback( $code )
 
 Adds a callback (like those given during construction). It is added to the end
 of the list of callbacks. Note that this can also be called on individual
 output objects.
 
-=back
+=head2 $dispatch->callbacks()
 
-=head2 Log levels
+Returns a list of the callbacks in a given output.
 
-=over 4
-
-=item * level_is_valid( $string )
+=head2 $dispatch->level_is_valid( $string )
 
 Returns true or false to indicate whether or not the given string is a
-valid log level.  Can be called as either a class or object method.
+valid log level. Can be called as either a class or object method.
 
-=item * would_log( $string )
+=head2 $dispatch->would_log( $string )
 
 Given a log level, returns true or false to indicate whether or not
 anything would be logged for that log level.
 
-=item * is_C<$level>
+=head2 $dispatch->is_C<$level>
 
 There are methods for every log level: C<is_debug()>, C<is_warning()>, etc.
 
 This returns true if the logger will log a message at the given level.
 
-=back
+=head2 $dispatch->add( Log::Dispatch::* OBJECT )
 
-=head2 Output objects
-
-=over
-
-=item * add( Log::Dispatch::* OBJECT )
-
-Adds a new L<output object|OUTPUT CLASSES> to the dispatcher.  If an object
+Adds a new L<output object|OUTPUT CLASSES> to the dispatcher. If an object
 of the same name already exists, then that object is replaced, with
 a warning if C<$^W> is true.
 
-=item * remove($)
+=head2 $dispatch->remove($)
 
 Removes the object that matches the name given to the remove method.
 The return value is the object being removed or undef if no object
 matched this.
 
-=item * output( $name )
+=head2 $dispatch->outputs()
 
-Returns the output object of the given name.  Returns undef or an empty
+Returns a list of output objects.
+
+=head2 $dispatch->output( $name )
+
+Returns the output object of the given name. Returns undef or an empty
 list, depending on context, if the given output does not exist.
 
-=back
+=head2 $dispatch->_die_with_message( message => $, carp_level => $ )
+
+This method is used by C<log_and_die> and will either die() or croak()
+depending on the value of C<message>: if it's a reference or it ends
+with a new line then a plain die will be used, otherwise it will
+croak.
 
 =head1 OUTPUT CLASSES
 
@@ -494,46 +537,46 @@ these, see their documentation for details.
 A name for the object (not the filename!). This is useful if you want to
 refer to the object later, e.g. to log specifically to it or remove it.
 
-By default a unique name will be generated.  You should not depend on the
+By default a unique name will be generated. You should not depend on the
 form of generated names, as they may change.
 
 =item * min_level ($)
 
-The minimum L<logging level|Log Levels> this object will accept. Required.
+The minimum L<logging level|LOG LEVELS> this object will accept. Required.
 
 =item * max_level ($)
 
-The maximum L<logging level|Log Levels> this object will accept.  By default
+The maximum L<logging level|LOG LEVELS> this object will accept. By default
 the maximum is the highest possible level (which means functionally that the
 object has no maximum).
 
 =item * callbacks( \& or [ \&, \&, ... ] )
 
 This parameter may be a single subroutine reference or an array
-reference of subroutine references.  These callbacks will be called in
+reference of subroutine references. These callbacks will be called in
 the order they are given and passed a hash containing the following keys:
 
  ( message => $log_message, level => $log_level )
 
 The callbacks are expected to modify the message and then return a
-single scalar containing that modified message.  These callbacks will
+single scalar containing that modified message. These callbacks will
 be called when either the C<log> or C<log_to> methods are called and
-will only be applied to a given message once.  If they do not return
-the message then you will get no output.  Make sure to return the
+will only be applied to a given message once. If they do not return
+the message then you will get no output. Make sure to return the
 message!
 
 =item * newline (0|1)
 
 If true, a callback will be added to the end of the callbacks list that adds
 a newline to the end of each message. Default is false, but some
-output classes may decide to make the default true. See L</NEWLINES> for more details.
+output classes may decide to make the default true.
 
 =back
 
 =head1 LOG LEVELS
 
 The log levels that Log::Dispatch uses are taken directly from the
-syslog man pages (except that I expanded them to full words).  Valid
+syslog man pages (except that I expanded them to full words). Valid
 levels are:
 
 =over 4
@@ -569,8 +612,8 @@ Log::Dispatch::Output and overriding the C<new> and C<log_message>
 methods. See the L<Log::Dispatch::Output> docs for more details.
 
 If you would like to create your own subclass for sending email then
-it is even simpler.  Simply subclass L<Log::Dispatch::Email> and
-override the C<send_email> method.  See the L<Log::Dispatch::Email>
+it is even simpler. Simply subclass L<Log::Dispatch::Email> and
+override the C<send_email> method. See the L<Log::Dispatch::Email>
 docs for more details.
 
 The logging levels that Log::Dispatch uses are borrowed from the standard
@@ -581,29 +624,29 @@ Log::Dispatch also allows the use of the full word as well ("error").
 
 =head2 Log::Dispatch::DBI
 
-Written by Tatsuhiko Miyagawa.  Log output to a database table.
+Written by Tatsuhiko Miyagawa. Log output to a database table.
 
 =head2 Log::Dispatch::FileRotate
 
-Written by Mark Pfeiffer.  Rotates log files periodically as part of
+Written by Mark Pfeiffer. Rotates log files periodically as part of
 its usage.
 
 =head2 Log::Dispatch::File::Stamped
 
-Written by Eric Cholet.  Stamps log files with date and time
+Written by Eric Cholet. Stamps log files with date and time
 information.
 
 =head2 Log::Dispatch::Jabber
 
-Written by Aaron Straup Cope.  Logs messages via Jabber.
+Written by Aaron Straup Cope. Logs messages via Jabber.
 
 =head2 Log::Dispatch::Tk
 
-Written by Dominique Dumont.  Logs messages to a Tk window.
+Written by Dominique Dumont. Logs messages to a Tk window.
 
 =head2 Log::Dispatch::Win32EventLog
 
-Written by Arthur Bergman.  Logs messages to the Windows event log.
+Written by Arthur Bergman. Logs messages to the Windows event log.
 
 =head2 Log::Log4perl
 
@@ -614,14 +657,14 @@ job. Created by Mike Schilli and Kevin Goess.
 
 =head2 Log::Dispatch::Config
 
-Written by Tatsuhiko Miyagawa.  Allows configuration of logging via a
+Written by Tatsuhiko Miyagawa. Allows configuration of logging via a
 text file similar (or so I'm told) to how it is done with log4j.
 Simpler than Log::Log4perl.
 
 =head2 Log::Agent
 
 A very different API for doing many of the same things that
-Log::Dispatch does.  Originally written by Raphael Manfredi.
+Log::Dispatch does. Originally written by Raphael Manfredi.
 
 =head1 SUPPORT
 
@@ -631,7 +674,26 @@ or via email at bug-log-dispatch@rt.cpan.org.
 
 Support questions can be sent to me at my email address, shown below.
 
-The code repository is at http://hg.urth.org/hg/Log-Dispatch.
+=head1 DONATIONS
+
+If you'd like to thank me for the work I've done on this module,
+please consider making a "donation" to me via PayPal. I spend a lot of
+free time creating free software, and would appreciate any support
+you'd care to offer.
+
+Please note that B<I am not suggesting that you must do this> in order
+for me to continue working on this particular software. I will
+continue to do so, inasmuch as I have in the past, for as long as it
+interests me.
+
+Similarly, a donation made in this way will probably not make me work
+on this software much more, unless I get so many donations that I can
+consider working on free software full time, which seems unlikely at
+best.
+
+To donate, log into PayPal and send money to autarch@urth.org or use
+the button on this page:
+L<http://www.urth.org/~autarch/fs-donation.html>
 
 =head1 SEE ALSO
 
@@ -646,16 +708,52 @@ L<Log::Dispatch::Syslog>
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Karen Etheridge Olaf Alders Olivier Mengué Rohan Carly Ross Attrill swartz@jonathan-swartzs-macbook-4.local swartz@pobox.com Whitney Jackson
+
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Olaf Alders <olaf@wundersolutions.com>
+
+=item *
+
+Olivier Mengué <dolmen@cpan.org>
+
+=item *
+
+Rohan Carly <se456@rohan.id.au>
+
+=item *
+
+Ross Attrill <ross.attrill@gmail.com>
+
+=item *
+
+swartz@jonathan-swartzs-macbook-4.local <swartz@jonathan-swartzs-macbook-4.local>
+
+=item *
+
+swartz@pobox.com <swartz@pobox.com>
+
+=item *
+
+Whitney Jackson <whitney.jackson@baml.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
