@@ -1,11 +1,10 @@
 package Log::Dispatch::Base;
-BEGIN {
-  $Log::Dispatch::Base::VERSION = '2.29';
-}
 
 use strict;
 use warnings;
 
+our $VERSION = '2.51';
+
 sub _get_callbacks {
     shift;
     my %p = @_;
@@ -13,10 +12,10 @@ sub _get_callbacks {
     return unless exists $p{callbacks};
 
     return @{ $p{callbacks} }
-        if UNIVERSAL::isa( $p{callbacks}, 'ARRAY' );
+        if ref $p{callbacks} eq 'ARRAY';
 
     return $p{callbacks}
-        if UNIVERSAL::isa( $p{callbacks}, 'CODE' );
+        if ref $p{callbacks} eq 'CODE';
 
     return;
 }
@@ -50,7 +49,7 @@ sub add_callback {
 
 # ABSTRACT: Code shared by dispatch and output objects.
 
-
+__END__
 
 =pod
 
@@ -60,7 +59,7 @@ Log::Dispatch::Base - Code shared by dispatch and output objects.
 
 =head1 VERSION
 
-version 2.29
+version 2.51
 
 =head1 SYNOPSIS
 
@@ -75,20 +74,18 @@ version 2.29
 Unless you are me, you probably don't need to know what this class
 does.
 
+=for Pod::Coverage add_callback
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
