@@ -1,15 +1,15 @@
 package Log::Dispatch::Email;
-BEGIN {
-  $Log::Dispatch::Email::VERSION = '2.29';
-}
 
 use strict;
 use warnings;
 
+our $VERSION = '2.51';
+
 use Log::Dispatch::Output;
 
 use base qw( Log::Dispatch::Output );
 
+use Devel::GlobalDestruction qw( in_global_destruction );
 use Params::Validate qw(validate SCALAR ARRAYREF BOOLEAN);
 Params::Validate::validation_options( allow_extra => 1 );
 
@@ -26,7 +26,7 @@ sub new {
                 type    => SCALAR,
                 default => "$program: log email"
             },
-            to   => { type => SCALAR | ARRAYREF },
+            to => { type => SCALAR | ARRAYREF },
             from => {
                 type     => SCALAR,
                 optional => 1
@@ -87,14 +87,27 @@ sub flush {
 sub DESTROY {
     my $self = shift;
 
-    $self->flush;
+    if (   in_global_destruction()
+        && $self->{buffered}
+        && @{ $self->{buffer} } ) {
+
+        my $name  = $self->name();
+        my $class = ref $self;
+        my $message
+            = "Log messages for the $name output (a $class object) remain unsent but the program is terminating.\n";
+        $message .= "The messages are:\n";
+        $message .= "  $_\n" for @{ $self->{buffer} };
+    }
+    else {
+        $self->flush();
+    }
 }
 
 1;
 
 # ABSTRACT: Base class for objects that send log messages via email
 
-
+__END__
 
 =pod
 
@@ -104,7 +117,7 @@ Log::Dispatch::Email - Base class for objects that send log messages via email
 
 =head1 VERSION
 
-version 2.29
+version 2.51
 
 =head1 SYNOPSIS
 
@@ -117,7 +130,7 @@ version 2.29
       my $self = shift;
       my %p    = @_;
 
-      # Send email somehow.  Message is in $p{message}
+      # Send email somehow. Message is in $p{message}
   }
 
 =head1 DESCRIPTION
@@ -127,6 +140,8 @@ Log::Dispatch::* objects that send their log messages via email.
 Implementing a subclass simply requires the code shown in the
 L<SYNOPSIS> with a real implementation of the C<send_email()> method.
 
+=for Pod::Coverage new log_message
+
 =head1 CONSTRUCTOR
 
 The constructor takes the following parameters in addition to the standard
@@ -136,63 +151,57 @@ parameters documented in L<Log::Dispatch::Output>:
 
 =item * subject ($)
 
-The subject of the email messages which are sent.  Defaults to "$0:
+The subject of the email messages which are sent. Defaults to "$0:
 log email"
 
 =item * to ($ or \@)
 
 Either a string or a list reference of strings containing email
-addresses.  Required.
+addresses. Required.
 
 =item * from ($)
 
-A string containing an email address.  This is optional and may not
+A string containing an email address. This is optional and may not
 work with all mail sending methods.
 
 =item * buffered (0 or 1)
 
 This determines whether the object sends one email per message it is
-given or whether it stores them up and sends them all at once.  The
+given or whether it stores them up and sends them all at once. The
 default is to buffer messages.
 
 =back
 
 =head1 METHODS
 
-=over 4
+This class provides the following methods:
 
-=item * send_email(%p)
+=head2 $email->send_email(%p)
 
-This is the method that must be subclassed.  For now the only
+This is the method that must be subclassed. For now the only
 parameter in the hash is 'message'.
 
-=item * flush
+=head2 $email->flush
 
 If the object is buffered, then this method will call the
 C<send_email()> method to send the contents of the buffer and then
 clear the buffer.
 
-=item * DESTROY
+=head2 $email->DESTROY
 
 On destruction, the object will call C<flush()> to send any pending
 email.
 
-=back
-
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
